import { Application, CSSUtils, Frame } from '@nativescript/core';
import { ref, watch, computed, onUnmounted, getCurrentInstance, readonly } from 'nativescript-vue';
import { useStorage } from '../useStorage';
import { getSystemTheme } from './util';
var removeSystemCssClass = CSSUtils.removeSystemCssClass;
import { createGlobalState } from '../globalState';
const useGlobalState = createGlobalState((storageKey, initialValue, themes) => {
    const storage = useStorage();
    const system = ref(getSystemTheme());
    const schema = ref(storage.getString(storageKey, initialValue.toString()));
    const modes = ref(themes);
    return { system, schema, modes };
});
export function useColorMode(options = {}) {
    const { initialValue = 'auto', storageKey = 'nativevueuse-color-scheme' } = options;
    const storage = useStorage();
    const { system, schema, modes } = useGlobalState(storageKey, initialValue, ['auto', 'light', 'dark', ...(options.modes ?? [])]);
    const theme = computed(() => (schema.value === 'auto' ? system.value : schema.value));
    let internalSchema = schema.value;
    Application.on('displayed', () => {
        processTheme();
    });
    Application.on('systemAppearanceChanged', () => {
        processTheme();
    });
    if (getCurrentInstance()) {
        onUnmounted(() => {
            Application.off('displayed', processTheme);
            Application.off('systemAppearanceChanged', processTheme);
        });
    }
    function processTheme() {
        system.value = getSystemTheme();
        if (schema.value === 'auto') {
            applyTheme(system.value);
        }
        else {
            applyTheme(schema.value);
        }
    }
    function applyTheme(themeToApply) {
        const rootView = Application.getRootView();
        if (rootView && !rootView.className?.includes(getClassFromTheme(themeToApply))) {
            schema.value = themeToApply;
            const rootViewClass = new Set();
            (Array.from(rootView.cssClasses).join(' ') ?? ' ').split(/\s+/).forEach((v) => v && rootViewClass.add(v));
            modes.value.forEach((theme) => {
                removeSystemCssClass(getClassFromTheme(theme));
                rootViewClass.delete(getClassFromTheme(theme));
            });
            let applyTheme = themeToApply;
            if (themeToApply.toLocaleLowerCase().trim() === 'auto') {
                applyTheme = getSystemTheme();
                Application.setAutoSystemAppearanceChanged(true);
                Application.systemAppearanceChanged(rootView, getSystemTheme());
            }
            else {
                Application.setAutoSystemAppearanceChanged(false);
            }
            rootViewClass.add(getClassFromTheme(applyTheme));
            rootView.className = Array.from(rootViewClass).join(' ');
            const frame = Frame.topmost();
            frame.backStack.forEach((backStack) => backStack.resolvedPage?._onCssStateChange());
            rootView._getRootModalViews()?.forEach((view) => {
                view?._onCssStateChange();
            });
            storage.setString(storageKey, themeToApply);
            console.log('Apply: ' + getClassFromTheme(themeToApply));
        }
        if (rootView && schema.value !== internalSchema) {
            internalSchema = schema.value;
            if (options.onChanged) {
                options.onChanged(theme.value);
            }
        }
    }
    watch(schema, () => {
        applyTheme(schema.value);
    });
    processTheme();
    return {
        schema,
        system: readonly(system),
        theme: readonly(theme),
        modes: readonly(modes),
    };
}
const getClassFromTheme = (theme) => CSSUtils.CLASS_PREFIX + theme.toLocaleLowerCase().trim();
//# sourceMappingURL=index.js.map