import { ViewRef } from '../types';
import { EventData, GestureEventData, ShownModallyData, View, ScrollEventData, ScrollView } from '@nativescript/core';
declare type ViewEventData<T> = Omit<EventData, 'object'> & {
    object: T;
};
declare type ViewGestureEventData<T> = Omit<GestureEventData, 'object'> & {
    object: T;
};
declare type ViewShownModallyData<T> = Omit<ShownModallyData, 'object'> & {
    object: T;
};
declare type ViewScrollEventData<T = ScrollView> = Omit<ScrollEventData, 'object'> & {
    object: T;
};
interface Event<T = View> {
    loaded?: (eventData: ViewEventData<T>) => void;
    unloaded?: (eventData: ViewEventData<T>) => void;
    layoutChanged?: (eventData: ViewEventData<T>) => void;
    tap?: (eventData: ViewGestureEventData<T>) => void;
    doubleTap?: (eventData: ViewGestureEventData<T>) => void;
    pinch?: (eventData: ViewGestureEventData<T>) => void;
    pan?: (eventData: ViewGestureEventData<T>) => void;
    swipe?: (eventData: ViewGestureEventData<T>) => void;
    rotation?: (eventData: ViewGestureEventData<T>) => void;
    longPress?: (eventData: ViewGestureEventData<T>) => void;
    touch?: (eventData: ViewGestureEventData<T>) => void;
    showingModally?: (eventData: ViewShownModallyData<T>) => void;
    shownModally?: (eventData: ViewShownModallyData<T>) => void;
    accessibilityBlur?: (eventData: ViewEventData<T>) => void;
    accessibilityFocus?: (eventData: ViewEventData<T>) => void;
    accessibilityFocusChanged?: (eventData: ViewEventData<T>) => void;
    accessibilityPerformEscape?: (eventData: ViewEventData<T>) => void;
    scroll?: (eventData: ViewScrollEventData) => void;
}
/**
 * Register using view.on on mounted, and view.off automatically on unmounted.
 *
 *
 * @param target
 * @param events
 */
export declare function useEventListener<T extends View = View>(target: T | ViewRef<T>, events: Event<T>): {
    cleanup: () => void;
};
export {};
