import { createNativeView, ref } from 'nativescript-vue';
import { ViewBase, getRootLayout } from '@nativescript/core';
/**
 * Utility for the RootLayout view.
 *
 * @param component
 * @param options
 */
export function useRootLayout(component, options) {
    const isShow = ref(false);
    const listeners = Object.entries(options?.on ?? {}).reduce((listeners, [key, value]) => {
        listeners['on' + key.charAt(0).toUpperCase() + key.slice(1)] = value;
        return listeners;
    }, {});
    const propsAndListeners = Object.assign({
        props: options?.props,
    }, listeners);
    const node = createNativeView(component, propsAndListeners);
    node.mount();
    const view = node.nativeView;
    view.on(ViewBase.unloadedEvent, () => {
        isShow.value = false;
        if (options?.onClose)
            options.onClose();
    });
    function show() {
        isShow.value = true;
        return getRootLayout().open(view, options?.rootLayoutOption);
    }
    function close() {
        getRootLayout().close(view);
    }
    return {
        show,
        close,
        isShow,
        view,
    };
}
//# sourceMappingURL=index.js.map